package sun.net.www.protocol.https;

import java.security.Permission;
import java.net.ProtocolException;
import java.util.List;
import java.util.Map;
import java.io.InputStream;
import java.io.OutputStream;
import java.security.Principal;
import javax.security.cert.X509Certificate;
import javax.net.ssl.SSLPeerUnverifiedException;
import java.security.cert.Certificate;
import java.net.Proxy;
import java.net.MalformedURLException;
import sun.net.util.IPAddressUtil;
import java.io.IOException;
import java.net.URL;
import javax.net.ssl.HttpsURLConnection;

public class HttpsURLConnectionImpl extends HttpsURLConnection
{
    protected DelegateHttpsURLConnection delegate;
    
    HttpsURLConnectionImpl(URL url, Handler handler) throws IOException {
        this(url, null, handler);
    }
    
    static URL checkURL(URL url) throws IOException {
        if (url != null && url.toExternalForm().indexOf(10) > -1) {
            throw new MalformedURLException("Illegal character in URL");
        }
        String checkAuthority = IPAddressUtil.checkAuthority(url);
        if (checkAuthority != null) {
            throw new MalformedURLException(checkAuthority);
        }
        return url;
    }
    
    HttpsURLConnectionImpl(URL url, Proxy proxy, Handler handler) throws IOException {
        super(checkURL(url));
        this.delegate = new DelegateHttpsURLConnection(this.url, proxy, handler, this);
    }
    
    protected HttpsURLConnectionImpl(URL url) throws IOException {
        super(url);
    }
    
    protected void setNewClient(URL url) throws IOException {
        this.delegate.setNewClient(url, false);
    }
    
    protected void setNewClient(URL url, boolean b) throws IOException {
        this.delegate.setNewClient(url, b);
    }
    
    protected void setProxiedClient(URL url, String s, int n) throws IOException {
        this.delegate.setProxiedClient(url, s, n);
    }
    
    protected void setProxiedClient(URL url, String s, int n, boolean b) throws IOException {
        this.delegate.setProxiedClient(url, s, n, b);
    }
    
    @Override
    public void connect() throws IOException {
        this.delegate.connect();
    }
    
    protected boolean isConnected() {
        return this.delegate.isConnected();
    }
    
    protected void setConnected(boolean connected) {
        this.delegate.setConnected(connected);
    }
    
    @Override
    public String getCipherSuite() {
        return this.delegate.getCipherSuite();
    }
    
    @Override
    public Certificate[] getLocalCertificates() {
        return this.delegate.getLocalCertificates();
    }
    
    @Override
    public Certificate[] getServerCertificates() throws SSLPeerUnverifiedException {
        return this.delegate.getServerCertificates();
    }
    
    public X509Certificate[] getServerCertificateChain() {
        try {
            return this.delegate.getServerCertificateChain();
        }
        catch (SSLPeerUnverifiedException ex) {
            return null;
        }
    }
    
    @Override
    public Principal getPeerPrincipal() throws SSLPeerUnverifiedException {
        return this.delegate.getPeerPrincipal();
    }
    
    @Override
    public Principal getLocalPrincipal() {
        return this.delegate.getLocalPrincipal();
    }
    
    @Override
    public synchronized OutputStream getOutputStream() throws IOException {
        return this.delegate.getOutputStream();
    }
    
    @Override
    public synchronized InputStream getInputStream() throws IOException {
        return this.delegate.getInputStream();
    }
    
    @Override
    public InputStream getErrorStream() {
        return this.delegate.getErrorStream();
    }
    
    @Override
    public void disconnect() {
        this.delegate.disconnect();
    }
    
    @Override
    public boolean usingProxy() {
        return this.delegate.usingProxy();
    }
    
    @Override
    public Map<String, List<String>> getHeaderFields() {
        return this.delegate.getHeaderFields();
    }
    
    @Override
    public String getHeaderField(String name) {
        return this.delegate.getHeaderField(name);
    }
    
    @Override
    public String getHeaderField(int n) {
        return this.delegate.getHeaderField(n);
    }
    
    @Override
    public String getHeaderFieldKey(int n) {
        return this.delegate.getHeaderFieldKey(n);
    }
    
    @Override
    public void setRequestProperty(String key, String value) {
        this.delegate.setRequestProperty(key, value);
    }
    
    @Override
    public void addRequestProperty(String key, String value) {
        this.delegate.addRequestProperty(key, value);
    }
    
    @Override
    public int getResponseCode() throws IOException {
        return this.delegate.getResponseCode();
    }
    
    @Override
    public String getRequestProperty(String key) {
        return this.delegate.getRequestProperty(key);
    }
    
    @Override
    public Map<String, List<String>> getRequestProperties() {
        return this.delegate.getRequestProperties();
    }
    
    @Override
    public void setInstanceFollowRedirects(boolean instanceFollowRedirects) {
        this.delegate.setInstanceFollowRedirects(instanceFollowRedirects);
    }
    
    @Override
    public boolean getInstanceFollowRedirects() {
        return this.delegate.getInstanceFollowRedirects();
    }
    
    @Override
    public void setRequestMethod(String requestMethod) throws ProtocolException {
        this.delegate.setRequestMethod(requestMethod);
    }
    
    @Override
    public String getRequestMethod() {
        return this.delegate.getRequestMethod();
    }
    
    @Override
    public String getResponseMessage() throws IOException {
        return this.delegate.getResponseMessage();
    }
    
    @Override
    public long getHeaderFieldDate(String name, long defaultValue) {
        return this.delegate.getHeaderFieldDate(name, defaultValue);
    }
    
    @Override
    public Permission getPermission() throws IOException {
        return this.delegate.getPermission();
    }
    
    @Override
    public URL getURL() {
        return this.delegate.getURL();
    }
    
    @Override
    public int getContentLength() {
        return this.delegate.getContentLength();
    }
    
    @Override
    public long getContentLengthLong() {
        return this.delegate.getContentLengthLong();
    }
    
    @Override
    public String getContentType() {
        return this.delegate.getContentType();
    }
    
    @Override
    public String getContentEncoding() {
        return this.delegate.getContentEncoding();
    }
    
    @Override
    public long getExpiration() {
        return this.delegate.getExpiration();
    }
    
    @Override
    public long getDate() {
        return this.delegate.getDate();
    }
    
    @Override
    public long getLastModified() {
        return this.delegate.getLastModified();
    }
    
    @Override
    public int getHeaderFieldInt(String name, int defaultValue) {
        return this.delegate.getHeaderFieldInt(name, defaultValue);
    }
    
    @Override
    public long getHeaderFieldLong(String name, long defaultValue) {
        return this.delegate.getHeaderFieldLong(name, defaultValue);
    }
    
    @Override
    public Object getContent() throws IOException {
        return this.delegate.getContent();
    }
    
    @Override
    public Object getContent(Class[] classes) throws IOException {
        return this.delegate.getContent(classes);
    }
    
    @Override
    public String toString() {
        return this.delegate.toString();
    }
    
    @Override
    public void setDoInput(boolean doInput) {
        this.delegate.setDoInput(doInput);
    }
    
    @Override
    public boolean getDoInput() {
        return this.delegate.getDoInput();
    }
    
    @Override
    public void setDoOutput(boolean doOutput) {
        this.delegate.setDoOutput(doOutput);
    }
    
    @Override
    public boolean getDoOutput() {
        return this.delegate.getDoOutput();
    }
    
    @Override
    public void setAllowUserInteraction(boolean allowUserInteraction) {
        this.delegate.setAllowUserInteraction(allowUserInteraction);
    }
    
    @Override
    public boolean getAllowUserInteraction() {
        return this.delegate.getAllowUserInteraction();
    }
    
    @Override
    public void setUseCaches(boolean useCaches) {
        this.delegate.setUseCaches(useCaches);
    }
    
    @Override
    public boolean getUseCaches() {
        return this.delegate.getUseCaches();
    }
    
    @Override
    public void setIfModifiedSince(long ifModifiedSince) {
        this.delegate.setIfModifiedSince(ifModifiedSince);
    }
    
    @Override
    public long getIfModifiedSince() {
        return this.delegate.getIfModifiedSince();
    }
    
    @Override
    public boolean getDefaultUseCaches() {
        return this.delegate.getDefaultUseCaches();
    }
    
    @Override
    public void setDefaultUseCaches(boolean defaultUseCaches) {
        this.delegate.setDefaultUseCaches(defaultUseCaches);
    }
    
    @Override
    protected void finalize() throws Throwable {
        this.delegate.dispose();
    }
    
    @Override
    public boolean equals(Object obj) {
        return this.delegate.equals(obj);
    }
    
    @Override
    public int hashCode() {
        return this.delegate.hashCode();
    }
    
    @Override
    public void setConnectTimeout(int connectTimeout) {
        this.delegate.setConnectTimeout(connectTimeout);
    }
    
    @Override
    public int getConnectTimeout() {
        return this.delegate.getConnectTimeout();
    }
    
    @Override
    public void setReadTimeout(int readTimeout) {
        this.delegate.setReadTimeout(readTimeout);
    }
    
    @Override
    public int getReadTimeout() {
        return this.delegate.getReadTimeout();
    }
    
    @Override
    public void setFixedLengthStreamingMode(int fixedLengthStreamingMode) {
        this.delegate.setFixedLengthStreamingMode(fixedLengthStreamingMode);
    }
    
    @Override
    public void setFixedLengthStreamingMode(long fixedLengthStreamingMode) {
        this.delegate.setFixedLengthStreamingMode(fixedLengthStreamingMode);
    }
    
    @Override
    public void setChunkedStreamingMode(int chunkedStreamingMode) {
        this.delegate.setChunkedStreamingMode(chunkedStreamingMode);
    }
}
